@@ -26,24 +26,39 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.#
 
-"""Test Esperanto images
-"""
+"""Test Esperanto images"""
 
 import os
 import fabio.esperantoimage
 from ..utilstest import UtilsTest
-
 import unittest
 import logging
 import numpy
+
 logger = logging.getLogger(__name__)
 
 
 class TestEsperanto(unittest.TestCase):
     # filename dim1 dim2 min max mean stddev
     TESTIMAGES = [
-        ("sucrose_1s__1_1.esperanto.bz2", 2048, 2048, -173, 66043, 16.31592893600464, 266.4471326013064),  # To validate
-        ("reference.esperanto.bz2", 256, 256, -1, 10963, 1.767120361328125, 50.87154169213312)
+        (
+            "sucrose_1s__1_1.esperanto.bz2",
+            2048,
+            2048,
+            -173,
+            66043,
+            16.31592893600464,
+            266.4471326013064,
+        ),  # To validate
+        (
+            "reference.esperanto.bz2",
+            256,
+            256,
+            -1,
+            10963,
+            1.767120361328125,
+            50.87154169213312,
+        ),
     ]
 
     def test_read(self):
@@ -59,10 +74,21 @@ class TestEsperanto(unittest.TestCase):
             obj = fabio.esperantoimage.EsperantoImage()
             obj.read(UtilsTest.getimage(name))
 
-            self.assertAlmostEqual(mini, obj.getmin(), 2, "getmin [%s,%s]" % (mini, obj.getmin()))
-            self.assertAlmostEqual(maxi, obj.getmax(), 2, "getmax [%s,%s]" % (maxi, obj.getmax()))
-            self.assertAlmostEqual(mean, obj.getmean(), 2, "getmean [%s,%s]" % (mean, obj.getmean()))
-            self.assertAlmostEqual(stddev, obj.getstddev(), 2, "getstddev [%s,%s]" % (stddev, obj.getstddev()))
+            self.assertAlmostEqual(
+                mini, obj.getmin(), 2, "getmin [%s,%s]" % (mini, obj.getmin())
+            )
+            self.assertAlmostEqual(
+                maxi, obj.getmax(), 2, "getmax [%s,%s]" % (maxi, obj.getmax())
+            )
+            self.assertAlmostEqual(
+                mean, obj.getmean(), 2, "getmean [%s,%s]" % (mean, obj.getmean())
+            )
+            self.assertAlmostEqual(
+                stddev,
+                obj.getstddev(),
+                2,
+                "getstddev [%s,%s]" % (stddev, obj.getstddev()),
+            )
 
             self.assertEqual(shape, obj.shape, "dim1")
 
@@ -73,27 +99,30 @@ class TestEsperanto(unittest.TestCase):
             obj = fabio.esperantoimage.EsperantoImage()
             obj.read(UtilsTest.getimage(name))
 
-            expected_keys = set([
-                'IMAGE',
-                'SPECIAL_CCD_1',
-                'SPECIAL_CCD_2',
-                'SPECIAL_CCD_3',
-                'SPECIAL_CCD_4',
-                'SPECIAL_CCD_5',
-                'TIME',
-                'MONITOR',
-                'PIXELSIZE',
-                'TIMESTAMP',
-                'GRIDPATTERN',
-                'STARTANGLESINDEG',
-                'ENDANGLESINDEG',
-                'GONIOMODEL_1',
-                'GONIOMODEL_2',
-                'WAVELENGTH',
-                'MONOCHROMATOR',
-                'ABSTORUN',
-                'HISTORY',
-                'ESPERANTO FORMAT'])
+            expected_keys = set(
+                [
+                    "IMAGE",
+                    "SPECIAL_CCD_1",
+                    "SPECIAL_CCD_2",
+                    "SPECIAL_CCD_3",
+                    "SPECIAL_CCD_4",
+                    "SPECIAL_CCD_5",
+                    "TIME",
+                    "MONITOR",
+                    "PIXELSIZE",
+                    "TIMESTAMP",
+                    "GRIDPATTERN",
+                    "STARTANGLESINDEG",
+                    "ENDANGLESINDEG",
+                    "GONIOMODEL_1",
+                    "GONIOMODEL_2",
+                    "WAVELENGTH",
+                    "MONOCHROMATOR",
+                    "ABSTORUN",
+                    "HISTORY",
+                    "ESPERANTO FORMAT",
+                ]
+            )
 
             upper_keys = set(i for i in obj.header.keys() if i.isupper())
             self.assertEqual(upper_keys, expected_keys)
@@ -107,9 +136,12 @@ class TestEsperanto(unittest.TestCase):
             new = fabio.open(dst)
             self.assertTrue(numpy.allclose(obj.data, new.data), msg="data are the same")
             for k, v in obj.header.items():
-                if k not in ("ESPERANTO FORMAT",
-                             ):
-                    self.assertEqual(v, new.header.get(k), "header differ on %s: %s vs %s" % (k, v, new.header.get(k)))
+                if k not in ("ESPERANTO FORMAT",):
+                    self.assertEqual(
+                        v,
+                        new.header.get(k),
+                        "header differ on %s: %s vs %s" % (k, v, new.header.get(k)),
+                    )
 
             # Test write compressed:
             obj.format = "AGI_BITFIELD"
@@ -120,9 +152,12 @@ class TestEsperanto(unittest.TestCase):
             new = fabio.open(dst)
             self.assertTrue(numpy.allclose(obj.data, new.data), msg="data are the same")
             for k, v in obj.header.items():
-                if k not in ("ESPERANTO FORMAT",
-                             ):
-                    self.assertEqual(v, new.header.get(k), "header differ on %s: %s vs %s" % (k, v, new.header.get(k)))
+                if k not in ("ESPERANTO FORMAT",):
+                    self.assertEqual(
+                        v,
+                        new.header.get(k),
+                        "header differ on %s: %s vs %s" % (k, v, new.header.get(k)),
+                    )
 
     def test_data(self):
         a = (numpy.random.random((257, 421)) * 100).round()
@@ -144,6 +179,6 @@ def suite():
     return testsuite
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     runner = unittest.TextTestRunner()
     runner.run(suite())
